@@ -19,6 +19,11 @@ sub run {
 
     $self->parse_opts;
 
+    if( $self->{local_lib} and -d  $self->{local_lib} ) {
+        require local::lib;
+        local::lib->import( $self->{local_lib} );
+    }
+
     $self->{'modules'}
         and push @modules, @{ $self->{'modules'} };
 
@@ -68,6 +73,7 @@ sub parse_opts {
         'h|help'       => sub { $self->help },
         'f|full!'      => \$self->{'full'},
         'i|input=s'    => \$self->{'input'},
+        'l|local-lib=s'=> \$self->{'local_lib'},
         'I|include=s@' => \$self->{'include'},
         'd|dev!'       => \$self->{'dev'},
         'q|quiet!'     => \$self->{'quiet'},
@@ -91,11 +97,12 @@ $0 [ OPTIONS ] Module Module Module...
 Provide a module's version, comfortably.
 
 OPTIONS
-    -f | --full     Output name and version (a la Module::Version 0.05)
-    -I | --include  Include any number of directories to include as well
-    -i | --input    Input file to read module names from
-    -d | --dev      Show developer versions as 0.01_01 instead of 0.0101
-    -q | --quiet    Do not error out if module doesn't exist
+    -f | --full      Output name and version (a la Module::Version 0.05)
+    -I | --include   Include any number of directories to include as well
+    -i | --input     Input file to read module names from 
+    -l | --local-lib Additional local::lib dir to search
+    -d | --dev       Show developer versions as 0.01_01 instead of 0.0101
+    -q | --quiet     Do not error out if module doesn't exist
 
 _END_HEREDOC
 }
@@ -114,7 +121,7 @@ Module::Version::App - Application implementation for Module::Version
 
 =head1 VERSION
 
-version 0.13
+version 0.200
 
 =head1 SYNOPSIS
 
